@@ -34,11 +34,15 @@ public:
         const char *data = PyUnicode_AsUTF8AndSize(src.ptr(), &size);
         if (data == NULL)
         {
+            PyErr_Clear();
             return false;
         }
 
         // this assumes that the stringref won't be retained after the function call
         ref = wpi::StringRef(data, size);
+
+        // src must be valid as long as this loader is valid
+        loader_life_support::add_patient(src);
         return true;
     }
 
